'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('./extends-dcc897fe.js');
var _styled = require('styled-components');
var React = require('react');
var web = require('./web-15d19f8b.js');
var propTypes = require('./prop-types-d00b0193.js');
var css = require('./css.js');
var springs = require('./springs.js');
var constants = require('./constants.js');
require('./index-daca4eba.js');
require('react-dom');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _styled__default = /*#__PURE__*/_interopDefaultLegacy(_styled);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

const LABELS_HEIGHT = 30;
const WIDTH_DEFAULT = 300;
const GAP = 0.9;
const FULL_DAY = 24; // hours, equivalent to rectangles drawn

function useMeasuredWidth() {
  const ref = React.useRef();
  const [measuredWidth, setMeasuredWidth] = React.useState(WIDTH_DEFAULT);
  const onResize = React.useCallback(() => {
    if (ref.current) {
      setMeasuredWidth(ref.current.clientWidth);
    }
  }, []);
  const onRef = React.useCallback(element => {
    ref.current = element;
    onResize();
  }, [onResize]);
  React.useEffect(() => {
    window.addEventListener('resize', onResize);
    return () => window.removeEventListener('resize', onResize);
  }, [onResize]);
  return [measuredWidth, onRef];
}

const OFFSET = 50;

var _StyledSvg = _styled__default['default']("svg").withConfig({
  displayName: "BarChart___StyledSvg",
  componentId: "i7yrcu-0"
})(["display:block"]);

var _StyledRect = _styled__default['default']("rect").withConfig({
  displayName: "BarChart___StyledRect",
  componentId: "i7yrcu-1"
})(["opacity:", ";"], p => p._css);

var _StyledRect2 = _styled__default['default']("rect").withConfig({
  displayName: "BarChart___StyledRect2",
  componentId: "i7yrcu-2"
})(["opacity:0.5;"]);

var _StyledText = _styled__default['default']("text").withConfig({
  displayName: "BarChart___StyledText",
  componentId: "i7yrcu-3"
})(["position:relative;alignment-baseline:middle;font-size:10px;font-weight:300;);", ";", ""], css.unselectable, p => p._css2);

var _StyledText2 = _styled__default['default']("text").withConfig({
  displayName: "BarChart___StyledText2",
  componentId: "i7yrcu-4"
})(["alignment-baseline:middle;font-size:12px;font-weight:300;", ";", ""], css.unselectable, p => p._css3);

function BarChart({
  animDelay,
  borderColor,
  color,
  dotRadius,
  height,
  label,
  labelColor,
  lines: linesProps,
  renderCheckpoints,
  reset,
  scales,
  springConfig,
  threshold,
  total,
  width: widthProps,
  ...props
}) {
  const [width, onSvgRef] = useMeasuredWidth();
  const lines = React.useMemo(() => {
    return linesProps.map(lineOrValues => Array.isArray(lineOrValues) ? {
      values: lineOrValues
    } : lineOrValues);
  }, [linesProps]); // the count of provided values

  const valuesCount = React.useMemo(() => {
    // All the values have the same length, so we can use the first one.
    return lines[0] ? lines[0].values.length : 0;
  }, [lines]); // the total amount of values

  const totalCount = React.useMemo(() => {
    // If no total is provided, the total is the number of provided values.
    return total > 0 && total > valuesCount ? total : valuesCount;
  }, [valuesCount, total]);
  const getX = React.useCallback(index => {
    return width / Math.max(1, totalCount - 1) * index;
  }, [width, totalCount]);
  const getRectX = React.useCallback(index => {
    return width / FULL_DAY * index + constants.GU;
  }, [width]);
  const getLabelPosition = React.useCallback((index, length) => {
    if (index === 0) {
      return 'start';
    }

    if (index === length - 1) {
      return 'end';
    }

    return 'middle';
  }, []);
  const labels = label;
  const chartHeight = height - (labels ? LABELS_HEIGHT : 0);
  return /*#__PURE__*/React__default['default'].createElement(web.Spring, {
    from: {
      progress: 0
    },
    to: {
      progress: 1
    },
    config: springConfig,
    delay: animDelay,
    reset: reset
  }, ({
    progress
  }) => /*#__PURE__*/React__default['default'].createElement(_StyledSvg, _extends._extends({
    ref: onSvgRef,
    viewBox: `0 0 ${width + OFFSET} ${height + constants.GU}`,
    width: widthProps || 'auto',
    height: "auto"
  }, props), /*#__PURE__*/React__default['default'].createElement("g", {
    mask: "url(#chart-mask)",
    transform: `translate(${-1 * constants.GU},${constants.GU})`
  }, totalCount > 0 && /*#__PURE__*/React__default['default'].createElement("path", {
    d: `
                  ${[...new Array(totalCount - 1)].reduce((path, _, index) => `${path} M ${getX(index)},${!index ? 0 : chartHeight} l 0,-8`, '')}
                `,
    stroke: borderColor,
    strokeWidth: "0"
  }), lines.map((line, lineIndex) => {
    return /*#__PURE__*/React__default['default'].createElement("g", {
      key: `line-plot-${line.id || lineIndex}`
    }, line.values.map((val, index) => {
      return /*#__PURE__*/React__default['default'].createElement(React__default['default'].Fragment, null, /*#__PURE__*/React__default['default'].createElement(_StyledRect, {
        x: getRectX(index),
        y: chartHeight - chartHeight * val * progress,
        width: width / FULL_DAY * GAP,
        height: chartHeight * val * progress,
        fill: line.color || color(lineIndex, {
          lines
        }),
        _css: val
      }), /*#__PURE__*/React__default['default'].createElement(_StyledRect2, {
        x: getRectX(index),
        y: chartHeight - chartHeight * val - constants.GU / 2,
        width: width / FULL_DAY * GAP,
        height: 2,
        fill: line.color || color(lineIndex, {
          lines
        })
      }));
    }));
  })), labels && /*#__PURE__*/React__default['default'].createElement("g", {
    transform: `translate(0,${chartHeight})`
  }, labels.map((label, index) => /*#__PURE__*/React__default['default'].createElement(_StyledText, {
    key: index,
    x: width / FULL_DAY * index + (index ? constants.GU : 0),
    y: LABELS_HEIGHT,
    textAnchor: getLabelPosition(index, labels.length),
    fill: labelColor,
    _css2: index % 2 !== 0 && `font-size: 6px;`
  }, label))), /*#__PURE__*/React__default['default'].createElement("g", {
    transform: `translate(${2 * constants.GU},${constants.GU})`
  }, scales && scales.map(({
    label,
    highlightColor
  }, index) => {
    const scaleLength = scales.length - 1;
    return /*#__PURE__*/React__default['default'].createElement(_StyledText2, {
      key: index,
      x: width - OFFSET / 4,
      y: chartHeight - chartHeight / scaleLength * index + constants.GU / 2,
      textAnchor: getLabelPosition(0, labels.length),
      fill: highlightColor || labelColor,
      _css3: highlightColor && `
                        font-weight: 800;
                      `
    }, label);
  })), threshold && /*#__PURE__*/React__default['default'].createElement(React__default['default'].Fragment, null, /*#__PURE__*/React__default['default'].createElement("line", {
    x1: 0,
    y1: chartHeight / (scales.length - 1) + constants.GU,
    x2: width,
    y2: chartHeight / (scales.length - 1) + constants.GU,
    style: {
      stroke: '#952828',
      strokeWidth: 2
    }
  }), ' ', /*#__PURE__*/React__default['default'].createElement("defs", null, /*#__PURE__*/React__default['default'].createElement("linearGradient", {
    id: "thresholdFill",
    x1: "0",
    x2: "0",
    y1: "0",
    y2: "1"
  }, /*#__PURE__*/React__default['default'].createElement("stop", {
    offset: "0%",
    stopColor: "red",
    stopOpacity: "0"
  }), /*#__PURE__*/React__default['default'].createElement("stop", {
    offset: "100%",
    stopColor: "#952828",
    stopOpacity: "30%"
  }))), /*#__PURE__*/React__default['default'].createElement("rect", {
    x: 0,
    y: 0,
    width: width,
    height: chartHeight / (scales.length - 1) + constants.GU,
    fill: "url(#thresholdFill)"
  }))));
}

BarChart.propTypes = {
  springConfig: propTypes.ExtendedPropTypes._spring,
  total: propTypes.ExtendedPropTypes.number,
  width: propTypes.ExtendedPropTypes.number,
  height: propTypes.ExtendedPropTypes.number,
  dotRadius: propTypes.ExtendedPropTypes.number,
  animDelay: propTypes.ExtendedPropTypes.number,
  borderColor: propTypes.ExtendedPropTypes.string,
  labelColor: propTypes.ExtendedPropTypes.string,
  lines: propTypes.ExtendedPropTypes.arrayOf(propTypes.ExtendedPropTypes.oneOfType([propTypes.ExtendedPropTypes.shape({
    id: propTypes.ExtendedPropTypes.number,
    values: propTypes.ExtendedPropTypes.arrayOf(propTypes.ExtendedPropTypes.number).isRequired,
    // numbers between 0 and 1
    color: propTypes.ExtendedPropTypes.string // overrides the color() prop if set

  }), // values can also be passed directly
  propTypes.ExtendedPropTypes.arrayOf(propTypes.ExtendedPropTypes.number)])),
  label: propTypes.ExtendedPropTypes.oneOfType([propTypes.ExtendedPropTypes.func, propTypes.ExtendedPropTypes._null, propTypes.ExtendedPropTypes.arrayOf('string')]),
  scales: propTypes.ExtendedPropTypes.arrayOf(propTypes.ExtendedPropTypes.string),
  renderCheckpoints: propTypes.ExtendedPropTypes.bool,
  reset: propTypes.ExtendedPropTypes.bool,
  threshold: propTypes.ExtendedPropTypes.bool,
  color: propTypes.ExtendedPropTypes.func
};
BarChart.defaultProps = {
  springConfig: springs.springs.lazy,
  total: -1,
  height: 200,
  dotRadius: 7 / 2,
  animDelay: 500,
  rendercheckpoints: false,
  reset: false,
  borderColor: 'rgba(209, 209, 209, 0.5)',
  labelColor: 'white',
  lines: [],
  scales: [],
  threshold: false,
  color: (index, {
    lines
  }) => `hsl(${(index * (360 / lines.length) + 40) % 360}, 60%, 70%)`
};

exports.default = BarChart;
//# sourceMappingURL=BarChart.js.map
