'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('./extends-dcc897fe.js');
var _styled = require('styled-components');
var React = require('react');
var index = require('./index-daca4eba.js');
var ButtonBase = require('./ButtonBase.js');
var environment = require('./environment.js');
var Theme = require('./Theme.js');
var css = require('./css.js');
var textStyles = require('./text-styles.js');
var constants = require('./constants.js');
require('./FocusVisible.js');
require('./defineProperty-74f274e0.js');
require('./keycodes.js');
require('./miscellaneous.js');
require('./theme-dark.js');
require('./theme-light.js');
require('./color.js');
require('./font.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _styled__default = /*#__PURE__*/_interopDefaultLegacy(_styled);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

// See src/icons/icon-size.js for the corresponding icon sizes.

const SIZE_STYLES = {
  normal: {
    textStyleName: 'body2',
    height: 6 * constants.GU,
    padding: 2 * constants.GU,
    iconPadding: 2 * constants.GU,
    minWidth: 27 * constants.GU,
    middleSpace: 1 * constants.GU
  },
  medium: {
    textStyleName: 'body3',
    height: 5 * constants.GU,
    padding: 2 * constants.GU,
    iconPadding: 1.5 * constants.GU,
    minWidth: 24 * constants.GU,
    middleSpace: 1 * constants.GU
  },
  small: {
    textStyleName: 'body3',
    height: 4 * constants.GU,
    padding: 1.5 * constants.GU,
    iconPadding: 1 * constants.GU,
    minWidth: 22 * constants.GU,
    middleSpace: 0.5 * constants.GU
  }
};

function getPadding(size, displayIcon, displayLabel) {
  const {
    padding,
    iconPadding
  } = SIZE_STYLES[size];

  if (displayIcon && !displayLabel) {
    return '0';
  }

  if (displayIcon && displayLabel) {
    return `0 ${padding}px 0 ${iconPadding}px`;
  }

  return `0 ${padding}px`;
}

function getWidth(size, displayIconOnly, wide) {
  const {
    height
  } = SIZE_STYLES[size];

  if (wide) {
    return '100%';
  }

  if (displayIconOnly) {
    return `${height}px`;
  }

  return 'auto';
}

function getMinWidth(size, displayLabelOnly) {
  const {
    minWidth
  } = SIZE_STYLES[size];
  return displayLabelOnly ? `${minWidth}px` : '0';
} // CSS styles related to the current size


function sizeStyles(size, wide, displayIcon, displayLabel) {
  const {
    height,
    textStyleName,
    middleSpace
  } = SIZE_STYLES[size];
  return {
    height: `${height}px`,
    middleSpace: displayIcon && displayLabel ? `${middleSpace}px` : '0',
    minWidth: getMinWidth(size, !displayIcon && displayLabel),
    padding: getPadding(size, displayIcon, displayLabel),
    textStyleCss: textStyles.textStyle(textStyleName),
    width: getWidth(size, displayIcon && !displayLabel, wide)
  };
} // CSS styles related to the current mode


function modeStyles(theme, mode, disabled) {
  if (disabled) {
    return {
      background: mode === 'primary' ? theme.disabled : theme.surfaceInteractive,
      border: mode === 'primary' ? '0' : `2px solid ${theme.disabled}`,
      color: theme.disabledContent,
      iconColor: theme.disabledContent
    };
  }

  if (mode === 'primary') {
    return {
      background: theme.accent,
      border: '0',
      color: theme.contentInverted,
      iconColor: theme.contentInverted,
      activeBackground: 'transparent',
      activeBorder: `2px solid ${theme.accent}`,
      activeColor: theme.surfaceContent,
      hoverBackground: theme.accentHover,
      hoverBorder: '0'
    };
  }

  return {
    background: 'transparent',
    border: `2px solid ${theme.contentBorder}`,
    color: theme.surfaceContent,
    iconColor: theme.surfaceContent,
    activeBorder: `2px solid ${theme.accent}`,
    hoverBorder: `4px solid ${theme.contentBorder}`
  };
}

var _StyledButtonBase = _styled__default['default'](ButtonBase['default']).withConfig({
  displayName: "Button___StyledButtonBase",
  componentId: "sc-14himgq-0"
})(["display:", ";align-items:center;justify-content:center;width:", ";height:", ";min-width:", ";padding:", ";", ";font-weight:600;", ";background:", ";color:", ";white-space:nowrap;border:", ";transition:all 50ms ease-in-out;&:hover{", ";", ";}&:active{", ";", ";", "}"], p => p._css, p => p._css2, p => p._css3, p => p._css4, p => p._css5, p => p._css6, css.unselectable, p => p._css7, p => p._css8, p => p._css9, p => p._css10, p => p._css11, p => p._css12, p => p._css13, p => p._css14);

var _StyledSpan = _styled__default['default']("span").withConfig({
  displayName: "Button___StyledSpan",
  componentId: "sc-14himgq-1"
})(["position:relative;top:-1px;display:flex;color:", ";margin-right:", ";"], p => p._css15, p => p._css16);

function BasicButton({
  children,
  disabled,
  display,
  icon,
  innerRef,
  label,
  mode,
  size,
  wide,
  ...props
}) {
  // prop warnings
  if (display === 'icon' && !icon) {
    environment.warn(`Button: the display "icon" was used without providing an icon.`);
  }

  if (!children && !label) {
    environment.warn('Button: please provide a label.');
  }

  const theme = Theme.useTheme();

  if (display === 'auto') {
    display = 'all';
  }

  const displayIcon = icon && (display === 'all' || display === 'icon');
  const displayLabel = label && (display === 'all' || display === 'label'); // Mode styles

  const {
    background,
    color,
    iconColor,
    border,
    activeBorder,
    activeBackground,
    activeColor,
    hoverBackground,
    hoverBorder
  } = React.useMemo(() => modeStyles(theme, mode, disabled), [mode, theme, disabled]); // Size styles

  const {
    height,
    middleSpace,
    minWidth,
    padding,
    textStyleCss,
    width
  } = React.useMemo(() => sizeStyles(size, wide, displayIcon, displayLabel), [size, wide, displayIcon, displayLabel]); // Use the label as a title when only the icon is displayed

  if (displayIcon && !displayLabel && label && typeof label === 'string') {
    props.title = label;
  }

  return /*#__PURE__*/React__default['default'].createElement(_StyledButtonBase, _extends._extends({
    ref: innerRef,
    focusRingSpacing: border === '0' ? 0 : 1,
    focusRingRadius: constants.RADIUS,
    disabled: disabled
  }, props, {
    _css: wide ? 'flex' : 'inline-flex',
    _css2: width,
    _css3: height,
    _css4: minWidth,
    _css5: padding,
    _css6: textStyleCss,
    _css7: background,
    _css8: color,
    _css9: border,
    _css10: hoverBackground && `background: ${hoverBackground}`,
    _css11: hoverBorder && `border: ${hoverBorder}`,
    _css12: activeBackground && `background: ${activeBackground}`,
    _css13: activeBorder && `border: ${activeBorder}`,
    _css14: activeColor && `color: ${activeColor}`
  }), children || /*#__PURE__*/React__default['default'].createElement(React__default['default'].Fragment, null, displayIcon && /*#__PURE__*/React__default['default'].createElement(_StyledSpan, {
    _css15: iconColor,
    _css16: middleSpace
  }, icon), displayLabel && {
    label
  }));
}

BasicButton.propTypes = {
  children: index.propTypes.node,
  disabled: index.propTypes.bool,
  display: index.propTypes.oneOf(['auto', 'all', 'icon', 'label']),
  icon: index.propTypes.node,
  innerRef: index.propTypes.any,
  label: index.propTypes.string,
  mode: index.propTypes.oneOf(['normal', 'primary']),
  size: index.propTypes.oneOf(['normal', 'medium', 'small']),
  wide: index.propTypes.bool
};
BasicButton.defaultProps = {
  disabled: false,
  display: 'auto',
  mode: 'normal',
  size: 'normal',
  wide: false
};
const Button = /*#__PURE__*/React__default['default'].forwardRef((props, ref) => /*#__PURE__*/React__default['default'].createElement(BasicButton, _extends._extends({
  innerRef: ref
}, props)));

exports.default = Button;
//# sourceMappingURL=Button.js.map
