import _extends from '../../../node_modules/@babel/runtime/helpers/extends.js';
import _styled from 'styled-components';
import React, { useMemo } from 'react';
import propTypes from '../../../node_modules/prop-types/index.js';
import ButtonBaseWithFocus from '../ButtonBase/ButtonBase.js';
import { warn } from '../../utils/environment.js';
import { useTheme } from '../../theme/Theme2.js';
import { unselectable } from '../../utils/css.js';
import { textStyle } from '../../style/text-styles.js';
import { RADIUS, GU } from '../../style/constants.js';

// See src/icons/icon-size.js for the corresponding icon sizes.

const SIZE_STYLES = {
  normal: {
    textStyleName: 'body2',
    height: 6 * GU,
    padding: 2 * GU,
    iconPadding: 2 * GU,
    minWidth: 27 * GU,
    middleSpace: 1 * GU
  },
  medium: {
    textStyleName: 'body3',
    height: 5 * GU,
    padding: 2 * GU,
    iconPadding: 1.5 * GU,
    minWidth: 24 * GU,
    middleSpace: 1 * GU
  },
  small: {
    textStyleName: 'body3',
    height: 4 * GU,
    padding: 1.5 * GU,
    iconPadding: 1 * GU,
    minWidth: 22 * GU,
    middleSpace: 0.5 * GU
  }
};

function getPadding(size, displayIcon, displayLabel) {
  const {
    padding,
    iconPadding
  } = SIZE_STYLES[size];

  if (displayIcon && !displayLabel) {
    return '0';
  }

  if (displayIcon && displayLabel) {
    return `0 ${padding}px 0 ${iconPadding}px`;
  }

  return `0 ${padding}px`;
}

function getWidth(size, displayIconOnly, wide) {
  const {
    height
  } = SIZE_STYLES[size];

  if (wide) {
    return '100%';
  }

  if (displayIconOnly) {
    return `${height}px`;
  }

  return 'auto';
}

function getMinWidth(size, displayLabelOnly) {
  const {
    minWidth
  } = SIZE_STYLES[size];
  return displayLabelOnly ? `${minWidth}px` : '0';
} // CSS styles related to the current size


function sizeStyles(size, wide, displayIcon, displayLabel) {
  const {
    height,
    textStyleName,
    middleSpace
  } = SIZE_STYLES[size];
  return {
    height: `${height}px`,
    middleSpace: displayIcon && displayLabel ? `${middleSpace}px` : '0',
    minWidth: getMinWidth(size, !displayIcon && displayLabel),
    padding: getPadding(size, displayIcon, displayLabel),
    textStyleCss: textStyle(textStyleName),
    width: getWidth(size, displayIcon && !displayLabel, wide)
  };
} // CSS styles related to the current mode


function modeStyles(theme, mode, disabled) {
  if (disabled) {
    return {
      background: mode === 'primary' ? theme.disabled : theme.surfaceInteractive,
      border: mode === 'primary' ? '0' : `2px solid ${theme.disabled}`,
      color: theme.disabledContent,
      iconColor: theme.disabledContent
    };
  }

  if (mode === 'primary') {
    return {
      background: theme.accent,
      border: '0',
      color: theme.contentInverted,
      iconColor: theme.contentInverted,
      activeBackground: 'transparent',
      activeBorder: `2px solid ${theme.accent}`,
      activeColor: theme.surfaceContent,
      hoverBackground: theme.accentHover,
      hoverBorder: '0'
    };
  }

  return {
    background: 'transparent',
    border: `2px solid ${theme.contentBorder}`,
    color: theme.surfaceContent,
    iconColor: theme.surfaceContent,
    activeBorder: `2px solid ${theme.accent}`,
    hoverBorder: `4px solid ${theme.contentBorder}`
  };
}

var _StyledButtonBase = _styled(ButtonBaseWithFocus).withConfig({
  displayName: "Button___StyledButtonBase",
  componentId: "sc-14himgq-0"
})(["display:", ";align-items:center;justify-content:center;width:", ";height:", ";min-width:", ";padding:", ";", ";font-weight:600;", ";background:", ";color:", ";white-space:nowrap;border:", ";transition:all 50ms ease-in-out;&:hover{", ";", ";}&:active{", ";", ";", "}"], p => p._css, p => p._css2, p => p._css3, p => p._css4, p => p._css5, p => p._css6, unselectable, p => p._css7, p => p._css8, p => p._css9, p => p._css10, p => p._css11, p => p._css12, p => p._css13, p => p._css14);

var _StyledSpan = _styled("span").withConfig({
  displayName: "Button___StyledSpan",
  componentId: "sc-14himgq-1"
})(["position:relative;top:-1px;display:flex;color:", ";margin-right:", ";"], p => p._css15, p => p._css16);

function BasicButton({
  children,
  disabled,
  display,
  icon,
  innerRef,
  label,
  mode,
  size,
  wide,
  ...props
}) {
  // prop warnings
  if (display === 'icon' && !icon) {
    warn(`Button: the display "icon" was used without providing an icon.`);
  }

  if (!children && !label) {
    warn('Button: please provide a label.');
  }

  const theme = useTheme();

  if (display === 'auto') {
    display = 'all';
  }

  const displayIcon = icon && (display === 'all' || display === 'icon');
  const displayLabel = label && (display === 'all' || display === 'label'); // Mode styles

  const {
    background,
    color,
    iconColor,
    border,
    activeBorder,
    activeBackground,
    activeColor,
    hoverBackground,
    hoverBorder
  } = useMemo(() => modeStyles(theme, mode, disabled), [mode, theme, disabled]); // Size styles

  const {
    height,
    middleSpace,
    minWidth,
    padding,
    textStyleCss,
    width
  } = useMemo(() => sizeStyles(size, wide, displayIcon, displayLabel), [size, wide, displayIcon, displayLabel]); // Use the label as a title when only the icon is displayed

  if (displayIcon && !displayLabel && label && typeof label === 'string') {
    props.title = label;
  }

  return /*#__PURE__*/React.createElement(_StyledButtonBase, _extends({
    ref: innerRef,
    focusRingSpacing: border === '0' ? 0 : 1,
    focusRingRadius: RADIUS,
    disabled: disabled
  }, props, {
    _css: wide ? 'flex' : 'inline-flex',
    _css2: width,
    _css3: height,
    _css4: minWidth,
    _css5: padding,
    _css6: textStyleCss,
    _css7: background,
    _css8: color,
    _css9: border,
    _css10: hoverBackground && `background: ${hoverBackground}`,
    _css11: hoverBorder && `border: ${hoverBorder}`,
    _css12: activeBackground && `background: ${activeBackground}`,
    _css13: activeBorder && `border: ${activeBorder}`,
    _css14: activeColor && `color: ${activeColor}`
  }), children || /*#__PURE__*/React.createElement(React.Fragment, null, displayIcon && /*#__PURE__*/React.createElement(_StyledSpan, {
    _css15: iconColor,
    _css16: middleSpace
  }, icon), displayLabel && {
    label
  }));
}

BasicButton.propTypes = {
  children: propTypes.node,
  disabled: propTypes.bool,
  display: propTypes.oneOf(['auto', 'all', 'icon', 'label']),
  icon: propTypes.node,
  innerRef: propTypes.any,
  label: propTypes.string,
  mode: propTypes.oneOf(['normal', 'primary']),
  size: propTypes.oneOf(['normal', 'medium', 'small']),
  wide: propTypes.bool
};
BasicButton.defaultProps = {
  disabled: false,
  display: 'auto',
  mode: 'normal',
  size: 'normal',
  wide: false
};
const Button = /*#__PURE__*/React.forwardRef((props, ref) => /*#__PURE__*/React.createElement(BasicButton, _extends({
  innerRef: ref
}, props)));

export default Button;
//# sourceMappingURL=Button.js.map
