import _styled from 'styled-components';
import React, { useRef, useState, useCallback } from 'react';
import propTypes from '../../../node_modules/prop-types/index.js';
import { useInside as o } from '../../../node_modules/use-inside/dist/index.js';
import DiscButton from '../DiscButton/DiscButton.js';
import Popover from '../Popover/Popover.js';
import { useTheme } from '../../theme/Theme2.js';
import IconQuestion from '../../icons/components/IconQuestion.js';
import { GU } from '../../style/constants.js';
import { textStyle } from '../../style/text-styles.js';

var _StyledDiscButton = _styled(DiscButton).withConfig({
  displayName: "Help___StyledDiscButton",
  componentId: "frwolf-0"
})(["margin-top:", "px;margin-left:", "px;"], p => p._css, p => p._css2);

var _StyledPopover = _styled(Popover).withConfig({
  displayName: "Help___StyledPopover",
  componentId: "frwolf-1"
})(["border:0;", ";background:white;color:", ";"], p => p._css3, p => p._css4);

var _StyledDiv = _styled("div").withConfig({
  displayName: "Help___StyledDiv",
  componentId: "frwolf-2"
})(["position:relative;max-width:", "px;padding:", "px;"], p => p._css5, p => p._css6);

function Help({
  hint,
  placement,
  children
}) {
  const buttonElement = useRef();
  const [visible, setVisible] = useState(false);
  const open = useCallback(() => setVisible(true), []);
  const close = useCallback(() => setVisible(false), []);
  const theme = useTheme();
  const [insideBoxHeading] = o('Box:heading');
  const [insideFieldLabel] = o('Field:label');
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(_StyledDiscButton, {
    ref: buttonElement,
    description: hint,
    onClick: open,
    size: 1.5 * GU,
    _css: insideFieldLabel ? -3 : 0,
    _css2: insideBoxHeading || insideFieldLabel ? 1 * GU : 0
  }, /*#__PURE__*/React.createElement(IconQuestion, {
    size: "tiny"
  })), /*#__PURE__*/React.createElement(_StyledPopover, {
    opener: buttonElement.current,
    visible: visible,
    onClose: close,
    placement: placement,
    _css3: textStyle('body3'),
    _css4: theme.contentInverted
  }, /*#__PURE__*/React.createElement(_StyledDiv, {
    _css5: 48 * GU,
    _css6: 2 * GU
  }, children)));
}

Help.propTypes = {
  hint: propTypes.string.isRequired,
  placement: propTypes.oneOf(['center'].concat(...['auto', 'top', 'right', 'bottom', 'left'].map(position => [position, `${position}-start`, `${position}-end`]))),
  children: propTypes.node.isRequired
};

export default Help;
//# sourceMappingURL=Help.js.map
